import { useState, createRef, useMemo, useEffect, createElement } from 'react';

var KEY_CODE = {
  BACKSPACE: 8,
  ARROW_LEFT: 37,
  ARROW_RIGHT: 39,
  DELETE: 46
};
var CONTAINER_DATA_ID = 'REACT_VERIFICATION_CODE_CONTAINER';
var index = (function (_ref) {
  var _ref$length = _ref.length,
      length = _ref$length === void 0 ? 4 : _ref$length,
      _ref$placeholder = _ref.placeholder,
      placeholder = _ref$placeholder === void 0 ? '·' : _ref$placeholder;

  var _React$useState = useState(-1),
      activeIndex = _React$useState[0],
      setActiveIndex = _React$useState[1];

  var _React$useState2 = useState(new Array(length).fill(placeholder)),
      value = _React$useState2[0],
      setValue = _React$useState2[1];

  var codeInputRef = createRef();
  var itemsRef = useMemo(function () {
    return [].concat(new Array(length)).map(function () {
      return createRef();
    });
  }, [length]);
  var isCodeRegex = new RegExp("^[0-9]{" + length + "}$");

  var getItem = function getItem(index) {
    return itemsRef[index].current;
  };

  var focusItem = function focusItem(index) {
    return getItem(index).focus();
  };

  var blurItem = function blurItem(index) {
    return getItem(index).blur();
  };

  var onItemFocus = function onItemFocus(index) {
    return function () {
      setActiveIndex(index);
      if (codeInputRef.current) codeInputRef.current.focus();
    };
  };

  var onItemKeyUp = function onItemKeyUp(_ref2) {
    var key = _ref2.key,
        keyCode = _ref2.keyCode;
    var newValue = [].concat(value);
    var nextIndex = activeIndex + 1;
    var prevIndex = activeIndex - 1;
    var isLast = nextIndex === length;
    var isDeleting = keyCode === KEY_CODE.DELETE || keyCode === KEY_CODE.BACKSPACE;

    if (isDeleting) {
      newValue[activeIndex] = placeholder;
      setValue(newValue);

      if (activeIndex > 0) {
        setActiveIndex(prevIndex);
        focusItem(prevIndex);
      }

      return;
    }

    if (Number.isNaN(+key)) return;
    if (codeInputRef.current) codeInputRef.current.value = '';
    newValue[activeIndex] = key;
    setValue(newValue);

    if (!isLast) {
      setActiveIndex(nextIndex);
      focusItem(nextIndex);
      return;
    }

    if (codeInputRef.current) codeInputRef.current.blur();
    getItem(activeIndex).blur();
    setActiveIndex(-1);
  };

  var onItemChange = function onItemChange(e) {
    var changeValue = e.target.value;
    var isCode = isCodeRegex.test(changeValue);
    if (!isCode) return;
    setValue(changeValue.split(''));
    blurItem(activeIndex);
  };

  useEffect(function () {
    var onDocumentClick = function onDocumentClick(e) {
      var targetIncludesContainer = e.composedPath().reduce(function (bool, path) {
        var _path$dataset;

        return bool || ((_path$dataset = path.dataset) === null || _path$dataset === void 0 ? void 0 : _path$dataset.reactInputVerificationCodeId) === CONTAINER_DATA_ID;
      }, false);
      if (!targetIncludesContainer) setActiveIndex(-1);
    };

    document.addEventListener('click', onDocumentClick);
    return function () {
      document.removeEventListener('click', onDocumentClick);
    };
  }, []);
  return createElement("div", {
    "data-react-input-verification-code-id": CONTAINER_DATA_ID,
    className: 'ReactInputVerificationCode__container',
    style: {
      '--activeIndex': activeIndex,
      '--itemsCount': length,
      '--itemWidth': '4.5rem',
      '--itemHeight': '5rem',
      '--itemSpacing': '1rem'
    }
  }, createElement("input", {
    ref: codeInputRef,
    className: 'ReactInputVerificationCode__input',
    autoComplete: 'one-time-code',
    type: 'text',
    inputMode: 'decimal',
    id: 'one-time-code',
    onChange: onItemChange,
    onKeyUp: onItemKeyUp
  }), itemsRef.map(function (ref, i) {
    return createElement("div", {
      key: i,
      ref: ref,
      role: 'button',
      tabIndex: 0,
      className: "ReactInputVerificationCode__item " + (activeIndex === i ? 'is-active' : ''),
      onFocus: onItemFocus(i)
    }, value[i] || placeholder);
  }));
});

export default index;
//# sourceMappingURL=index.modern.js.map
